---
title: From VEP
---

## List of features

::: gentropy.dataset.l2g_features.vep.VepMeanFeature
::: gentropy.dataset.l2g_features.vep.VepMeanNeighbourhoodFeature
::: gentropy.dataset.l2g_features.vep.VepMaximumFeature
::: gentropy.dataset.l2g_features.vep.VepMaximumNeighbourhoodFeature

## Common logic

::: gentropy.dataset.l2g_features.vep.common_vep_feature_logic
::: gentropy.dataset.l2g_features.vep.common_neighbourhood_vep_feature_logic
